Multiple Subset Sum Solver
Description: Solves subset sum problem and multiple subset sum problem. It returns a set of decomposed integers.

# Solving subset sum problem and multiple subset sum problem.

It solves subset sum problem and multiple subset sum problem. This program was implemented in Rust and WebAssembly. The calulation is done in your browser without communicating with servers.

Please input values below.

Subset array (required)
Target array or value (required)
Maximum subset length (required when target is an array)
Maximum target length (required)
The number of candidates (required when target is an array)

Go back to the main page.